"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graylog2_1 = require("graylog2");
var GraylogAdapter = /** @class */ (function () {
    function GraylogAdapter(config) {
        this.config = config;
        this.info = this.info.bind(this);
        this.error = this.error.bind(this);
        this.warn = this.warn.bind(this);
        this.debug = this.debug.bind(this);
        this.setup = this.setup.bind(this);
        this.graylog = this.setup();
    }
    GraylogAdapter.prototype.info = function (log) {
        this.graylog.info(GraylogAdapter.messageStringify(log.message), log.meta);
    };
    GraylogAdapter.prototype.error = function (log) {
        this.graylog.error(GraylogAdapter.messageStringify(log.message), log.meta);
    };
    GraylogAdapter.prototype.warn = function (log) {
        this.graylog.warning(GraylogAdapter.messageStringify(log.message), log.meta);
    };
    GraylogAdapter.prototype.debug = function (log) {
        this.graylog.debug(GraylogAdapter.messageStringify(log.message), log.meta);
    };
    GraylogAdapter.prototype.validate = function () {
        return !!(this.config.facility && this.config.host && this.config.hostname && this.config.port);
    };
    GraylogAdapter.messageStringify = function (message) {
        var mappedMessage = message;
        if (typeof mappedMessage !== 'string') {
            mappedMessage = JSON.stringify(message);
        }
        return mappedMessage;
    };
    GraylogAdapter.prototype.setup = function () {
        return new graylog2_1.graylog({
            servers: [
                {
                    host: this.config.host,
                    port: this.config.port
                }
            ],
            hostname: this.config.hostname,
            facility: this.config.facility,
            bufferSize: this.config.bufferSize || 1400
        });
    };
    return GraylogAdapter;
}());
exports.GraylogAdapter = GraylogAdapter;
