"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
var types_1 = require("../types");
var log_mapper_1 = require("../mappers/log-mapper");
var logLevels = (_a = {},
    _a[types_1.LogLevel.error] = 3,
    _a[types_1.LogLevel.warn] = 4,
    _a[types_1.LogLevel.info] = 6,
    _a[types_1.LogLevel.debug] = 7,
    _a);
var Logger = /** @class */ (function () {
    function Logger(props) {
        this.adapters = props.adapters.filter(function (adapter) { return adapter.validate(); });
    }
    Logger.prototype.info = function (action, message, requestContext) {
        var _this = this;
        var logDetail = log_mapper_1.mapLogDetail(message, action, requestContext);
        this.adapters.forEach(function (adapter) { return _this.sendLog(adapter.info, logDetail, types_1.LogLevel.info); });
    };
    Logger.prototype.error = function (action, message, requestContext) {
        var _this = this;
        var logDetail = log_mapper_1.mapLogDetail(message, action, requestContext);
        this.adapters.forEach(function (adapter) { return _this.sendLog(adapter.error, logDetail, types_1.LogLevel.error); });
    };
    Logger.prototype.warn = function (action, message, requestContext) {
        var _this = this;
        var logDetail = log_mapper_1.mapLogDetail(message, action, requestContext);
        this.adapters.forEach(function (adapter) { return _this.sendLog(adapter.warn, logDetail, types_1.LogLevel.warn); });
    };
    Logger.prototype.debug = function (action, message, requestContext) {
        var _this = this;
        var logDetail = log_mapper_1.mapLogDetail(message, action, requestContext);
        this.adapters.forEach(function (adapter) { return _this.sendLog(adapter.debug, logDetail, types_1.LogLevel.debug); });
    };
    Logger.prototype.getLogLevel = function () {
        var logLevelAsText = process.env.LOG_LEVEL || types_1.LogLevel.warn;
        var level = logLevels[logLevelAsText];
        if (typeof level === 'undefined') {
            level = logLevels[types_1.LogLevel.warn];
        }
        return level;
    };
    Logger.prototype.sendLog = function (log, logDetail, level) {
        var logLevel = this.getLogLevel();
        if (logLevels[level] <= logLevel) {
            log(logDetail);
        }
    };
    return Logger;
}());
exports.Logger = Logger;
