"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var v4_1 = __importDefault(require("uuid/v4"));
var defaultOptions = {
    generateCorrelationId: false
};
var ExpressLogContextMiddleware = function (options) {
    if (options === void 0) { options = defaultOptions; }
    return function (req, res, next) {
        var query = req.query;
        req.logContext = {
            currentUrl: req.originalUrl,
            userAgent: req.header('user-agent'),
            refererUrl: req.header('referer'),
            correlationId: req.header('x-correlation-id') || req.header('x-correlationid'),
            ip: req.header('True-Client-IP') ||
                req.header('X-Client-IP') ||
                req.header('CF-Connecting-IP') ||
                req.header('Client-IP') ||
                req.header('x-real-ip') ||
                req.ip
        };
        if (query && query.storefrontId) {
            req.logContext.storefrontId = query.storefrontId;
        }
        if (query && query.language) {
            req.logContext.language = query.language;
        }
        if (query && query.culture) {
            req.logContext.culture = query.culture;
        }
        if (req.user) {
            req.logContext.userId = req.user.id;
        }
        if (options.generateCorrelationId && !req.logContext.correlationId) {
            req.logContext.correlationId = v4_1.default();
        }
        next();
    };
};
exports.ExpressLogContextMiddleware = ExpressLogContextMiddleware;
